@@ -240,7 +240,10 @@ class RackspaceMonitoringDriver(MonitoringDriver):
     def _url_to_obj_ids(self, url):
         rv = {}
         rp = self.connection.request_path
+
         path = urlparse.urlparse(url).path
+        # removed duplicated slashes
+        path = path.replace('//', '/')
 
         if path.startswith(rp):
             # remove version string stuff
@@ -248,7 +251,9 @@ class RackspaceMonitoringDriver(MonitoringDriver):
 
         chunks = path.split('/')[1:]
 
-        for i in range(0, len(chunks), 2):
+        # We start from 1 because we want to ignore tenant id which is first
+        # part of the url component
+        for i in range(1, len(chunks), 2):
             chunk = chunks[i]
 
             if not chunk:
@@ -553,16 +558,21 @@ class RackspaceMonitoringDriver(MonitoringDriver):
         data = {'who': kwargs.get('who'),
                 'why': kwargs.get('why'),
                 'label': kwargs.get('label'),
-                'timeout': kwargs.get('timeout', 29),
-                'period': kwargs.get('period', 30),
                 'monitoring_zones_poll': kwargs.get('monitoring_zones', None),
                 'target_alias': kwargs.get('target_alias'),
                 'target_resolver': kwargs.get('target_resolver'),
+                'target_hostname': kwargs.get('target_hostname'),
                 'type': kwargs.get('type'),
                 'disabled': kwargs.get('disabled', None),
                 'details': kwargs.get('details'),
                 }
 
+        if 'period' in kwargs:
+            data['period'] = kwargs['period']
+
+        if 'timeout' in kwargs:
+            data['timeout'] = kwargs['timeout']
+
         for k in data.keys():
             if data[k] is not None:
                 filtered[k] = data[k]
